==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebCardHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardHeaderDescription } from "./WebCardHeaderDescription";
/**
 * @hidden
 */
var WebCardHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebCardHeaderDescriptionMetadata, _super);
    function WebCardHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardHeaderDescriptionMetadata.b = function (a) {
        if (WebCardHeaderDescriptionMetadata.a == null) {
            WebCardHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardHeaderDescriptionMetadata.c(WebCardHeaderDescriptionMetadata.a);
        }
        if (a.g(WebCardHeaderDescriptionMetadata.a)) {
            return;
        }
        a.s(WebCardHeaderDescriptionMetadata.a);
    };
    WebCardHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardHeader");
    };
    WebCardHeaderDescriptionMetadata.d = function (a) {
        WebCardHeaderDescriptionMetadata.b(a);
        a.u("WebCardHeader", function () { return new WebCardHeaderDescription(); });
        a.t("WebCardHeader", WebCardHeaderDescriptionMetadata.a);
    };
    WebCardHeaderDescriptionMetadata.$t = markType(WebCardHeaderDescriptionMetadata, 'WebCardHeaderDescriptionMetadata');
    WebCardHeaderDescriptionMetadata.a = null;
    return WebCardHeaderDescriptionMetadata;
}(Base));
export { WebCardHeaderDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebCardHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardHeaderDescription } from "./WebCardHeaderDescription";
/**
 * @hidden
 */
var WebCardHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebCardHeaderDescriptionMetadata, _super);
    function WebCardHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardHeaderDescriptionMetadata.b = function (a) {
        if (WebCardHeaderDescriptionMetadata.a == null) {
            WebCardHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardHeaderDescriptionMetadata.c(WebCardHeaderDescriptionMetadata.a);
        }
        if (a.j(WebCardHeaderDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCardHeaderDescriptionMetadata.a);
    };
    WebCardHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardHeader");
        a.item("__tagNameWC", "String:igc-card-header");
    };
    WebCardHeaderDescriptionMetadata.d = function (a) {
        WebCardHeaderDescriptionMetadata.b(a);
        a.aa("WebCardHeader", function () { return new WebCardHeaderDescription(); });
        a.z("WebCardHeader", WebCardHeaderDescriptionMetadata.a);
    };
    WebCardHeaderDescriptionMetadata.$t = markType(WebCardHeaderDescriptionMetadata, 'WebCardHeaderDescriptionMetadata');
    WebCardHeaderDescriptionMetadata.a = null;
    return WebCardHeaderDescriptionMetadata;
}(Base));
export { WebCardHeaderDescriptionMetadata };
